extern DRIVER mboxdriver;
extern DRIVER imapdriver;
extern DRIVER nntpdriver;
extern DRIVER pop3driver;
extern DRIVER mixdriver;
extern DRIVER mxdriver;
extern DRIVER mbxdriver;
extern DRIVER tenexdriver;
extern DRIVER mtxdriver;
extern DRIVER mhdriver;
extern DRIVER mmdfdriver;
extern DRIVER unixdriver;
extern DRIVER newsdriver;
extern DRIVER philedriver;
extern DRIVER dummydriver;
extern AUTHENTICATOR auth_ext;
extern AUTHENTICATOR auth_md5;
extern AUTHENTICATOR auth_pla;
extern AUTHENTICATOR auth_log;
extern AUTHENTICATOR auth_bea;
extern AUTHENTICATOR auth_oa2;
int pith_ssl_encryption_version(char *);
